package org.deken.game.component;

import java.awt.*;
import org.deken.game.input.InputMouseAction;
import org.deken.game.sprites.SpriteSize;

/**
 * <p>Title: GameContainer</p>
 *
 * <p>Description: The object is for storing other GameComponents, that the user
 * interacts with. The container can have a "title bar", it can have borders
 * (graphic images), and it has everything that a GameComponent has. Since
 * elements of the game or images, the components that this can hold must be
 * predefined and set, usually in a grid pattern.</p>
 *
 * <p>Copyright: Copyright (c) 2006</p>
 *
 * <p>@author Gary Deken</p>
 *
 * @version 1.0
 */
public abstract class GameContainer extends GameComponent {
   protected boolean grabbed = false;

   /**
    * GameContainer
    */
   public GameContainer() {
   }

   /**
    *
    * @param inputMouseAction
    */
   public GameContainer(InputMouseAction inputMouseAction) {
      super(inputMouseAction);

   }

   /**
    * 
    * @param height Height of the container
    * @param width Width of the container
    * @param inputMouseAction
    */
   public GameContainer(int height, int width, InputMouseAction inputMouseAction) {
      super(inputMouseAction);
      size = new SpriteSize(height, width);
   }

   public boolean imageUpdate(Image img, int infoflags, int x, int y, int width,
      int height) {
      return false;
   }

   public void setGrabbed(boolean grabbed) {
      this.grabbed = grabbed;
   }

   public boolean isGrabbed() {
      return grabbed;
   }
}
