/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package org.deken.game.component;

import java.awt.Color;
import java.awt.Font;
import org.deken.game.animation.Animation;
import org.deken.game.graphics.GameGFX;
import org.deken.game.input.InputMouseAction;
import org.deken.game.map.GameLocation;
import org.deken.game.sprites.SpriteSize;

/**
 * <p>Title: GameLabel</p>
 *
 * <p>Description: </p>
 *
 * <p>Copyright: Copyright (c) Mar 6, 2011</p>
 *
 * @author Gary Deken<
 * @version 1.0
 */
public class GameLabel extends GameComponent {
   private GameText gameText;
   private Animation animation;

   /**
    *
    * @param text
    */
   public GameLabel(String text) {
      this(text, new Font(Font.SANS_SERIF, Font.PLAIN, 10), Color.black);
   }

   /**
    * 
    * @param text
    * @param font
    * @param fontColor
    */
   public GameLabel(String text, Font font, Color fontColor) {
      this(new GameText(text, font, fontColor));
   }

   public GameLabel(GameText gameText) {
      super();
      this.gameText = gameText;
   }

   /**
    * 
    * @param animation
    */
   public GameLabel(Animation animation) {
      super();
      this.animation = animation;
   }

   @Override
   public void update(long elapseTime) {
      if (gameText == null) {
         animation.update(elapseTime);
      }
   }

   @Override
   public void draw(int xOffset, int yOffset) {
      if (gameText == null) {
         if (invalid) {
            positionHorizontalAlignment();
            positionVerticalAlignment();
         }
         if (parent != null) {
            animation.draw(xOffset + (int) location.x, yOffset + (int) location.y);
         }
         else {
            animation.draw((int) location.x, (int) location.y);
         }
      }
      else {
         if (gameText.isInvalid()) {
            gameText.validate();
            // get size for string and font.
            size = gameText.getSize();
            invalid = false;
            positionHorizontalAlignment();
            positionVerticalAlignment();
         }
         GameGFX.gfx().setColor(gameText.getFontColor());
         GameGFX.gfx().setFont(gameText.getFont());
         if (parent != null) {
            GameGFX.gfx().drawString(gameText.getText(), xOffset + (int) location.x, yOffset + (int) location.y + gameText.getTextOffset());
         }
         else {
            GameGFX.gfx().drawString(gameText.getText(), (int) location.x, (int) location.y + gameText.getTextOffset());
         }
      }
   }

   public GameText getGameText() {
      return gameText;
   }

   public void setGameText(GameText gameText) {
      this.gameText = gameText;
   }

   public void notifyListener(InputMouseAction inputMouseAction) {
      throw new UnsupportedOperationException("Not supported yet.");
   }

   /**
    *
    * @return GameLabel
    */
   @Override
   public Object clone() {
      GameLabel that;
      if (gameText == null) {
         that = new GameLabel((Animation) this.animation.clone());
      }
      else {
         that = new GameLabel(gameText);
      }
      that.size = (SpriteSize) this.size.clone();
      that.location = new GameLocation(this.location.x, this.location.y);
      that.gameText = (GameText) this.gameText.clone();
      that.invalid = true;

      return that;
   }



}
